@@ -8,8 +8,13 @@ from typing import List, Optional
 import shopify
 
 from .adapters import to_metafield_definition, to_shopify_book, to_shopify_shop
-from .schema import (CreateBookInput, CreateMetafieldDefinitionInput,
-                     MetafieldDefinition, MetafieldType, ShopifyBook)
+from .schema import (
+    CreateBookInput,
+    CreateMetafieldDefinitionInput,
+    MetafieldDefinition,
+    MetafieldType,
+    ShopifyBook,
+)
 from .utils import concunrrently_handle_tasks
 
 document = (Path(__file__).resolve().parent / "document.graphql").read_text()
@@ -194,6 +199,13 @@ class ShopifyBookService:
                 type=MetafieldType.multi_line_text_field,
             )
         )
+        self._create_metafield_definition(
+            CreateMetafieldDefinitionInput(
+                name="Backorder",
+                key="backorder",
+                type=MetafieldType.boolean,
+            )
+        )
 
     def _get_metafield_definitions(self) -> List[MetafieldDefinition]:
         """
