@@ -9,8 +9,6 @@ from pydantic import BaseModel, validator
 
 from .validators import is_valid_isbn, is_valid_url, sanitize_isbn
 
-DEFAULT_LOCATION_ID = 80824303919
-
 
 class QuerySchema(BaseModel):
     pass
@@ -48,17 +46,12 @@ class ShopifyBook(QuerySchema):
         return int(self.gid.split("/")[-1])
 
 
-class ProductType(Enum):
-    book = "Books"
-    textbook = "Textbook"
-
-
 class CreateBookInput(MutationSchema):
     isbn: str
     title: str
     author: str
     price: Decimal
-    location_id: int = DEFAULT_LOCATION_ID
+    is_backorder: bool = True
     product_type: str = "Textbook"
     subtitle: t.Optional[str] = None
     description: t.Optional[str] = None
@@ -94,11 +87,6 @@ class CreateBookInput(MutationSchema):
                     "sku": self.isbn,
                     "barcode": self.isbn,
                     "price": str(self.price),
-                    "inventoryPolicy": "CONTINUE",
-                    "inventoryQuantities": {
-                        "availableQuantity": 0,
-                        "locationId": f"gid://shopify/Location/{self.location_id}",
-                    },
                 }
             ],
             "productCategory": {
@@ -120,6 +108,7 @@ class CreateBookInput(MutationSchema):
                     "namespace": "book",
                     "value": self.staff_comment,
                 },
+                {"key": "backorder", "namespace": "book", "value": self.is_backorder},
             ],
         }
         if self.cover_image:
